@@ -1,12 +1,10 @@
-from .summarize_recordings import summarize_recordings
-from .sort_recordings import sort_recordings
-from .sort_recordings import multi_sort_recordings
-from .summarize_sortings import summarize_sortings
-from .compare_sortings_with_truth import compare_sortings_with_truth, GenSortingComparisonTable
+from .compare_sortings_with_truth import GenSortingComparisonTable, GenSortingComparisonTableNew
 from .aggregate_sorting_results import aggregate_sorting_results
 from .compute_units_info import compute_units_info, ComputeUnitsInfo
+from .computerecordinginfo import ComputeRecordingInfo
 from .bandpass_filter import bandpass_filter
 from .whiten import whiten
 from .sortingcomparison import SortingComparison
+from .sort_recordings import find_sorter_processor_and_container
 # from .sort_recordings import IronClust
 # from .sort_recordings import KiloSort
